const system = require("../../../system");
const crypto = require('crypto');
var settings = require("../../../../config/settings");
class feishuLoginService{
  constructor() {
    this.utilsFeishuSve = system.getObject("service.utilsSve.utilsFeishuSve");
    this.utilsAuthSve = system.getObject("service.utilsSve.utilsAuthSve");
  };
  //用户登录
  async checkAndLogin(pobj){
    if(!pobj.code){
      return system.getResultFail(-100, "code参数不能为空");
    }
    
    //获取 app_access_token（应用商店应用）
    var appAccessTokenRes = await this.utilsFeishuSve.getAppAccessToken();
    if(appAccessTokenRes.status!=0){
      return appAccessTokenRes;
    }
    var app_access_token = appAccessTokenRes.data;

    //获取飞书登录用户身份
    var userAccessTokenParams = {
      "code":pobj.code,"app_access_token":app_access_token,"open_id":pobj.open_id || ""
    };
    var userAccessTokenRes = await this.utilsFeishuSve.getUserAccessToken(userAccessTokenParams);
    if(userAccessTokenRes.status!=0){
      return userAccessTokenRes;
    }
    var userAccessTokenObj = userAccessTokenRes.data;
    
    //帐号登录---若用户信息已存在 则返回userpin 不存在则返回空
    var loginByUserNameParams={
          "actionType": "getLoginByUserName",
          "actionBody":    {
              "open_id":userAccessTokenObj.open_id
          }
    };
    var loginByUserNameRes = await this.getLoginByUserName(loginByUserNameParams);
    if(loginByUserNameRes && loginByUserNameRes.status==0){
      return loginByUserNameRes;//获取userpin直接返回
    }

    //获取飞书用户信息
    var userInfoParams={
      user_access_token:userAccessTokenObj.access_token
    };
    var userInfoRes = await this.utilsFeishuSve.getUserInfo(userInfoParams);
    if(userInfoRes.status!=0){
      return userInfoRes;
    }
    var userInfoObj = userInfoRes.data;
    var createUserParams = {
      // uapp_id,channel_userid,channel_username,channel_nickname,open_id,he
    };
    loginByUserNameParams={
          "actionType": "getLoginByUserName",
          "actionBody":    {
              "open_id":userAccessTokenObj.open_id,
              "channelUserId":userInfoObj.mobile,// Y 渠道用户ID 
              "channelUserName":userInfoObj.name,// N 渠道用户名
              "mobile":userInfoObj.mobile, // N 渠道用户手机号
              "nickName":userInfoObj.name, // N 用户昵称
              "email":userInfoObj.eamil,//邮箱
              "head_url":userInfoObj.avatar_url //头像
          }
    };
    loginByUserNameRes = await this.getLoginByUserName(loginByUserNameParams);
    if(loginByUserNameRes && loginByUserNameRes.status==0){
      return loginByUserNameRes;//获取userpin直接返回
    }
    return system.getResultFail("获取userpin失败");
  }

  //渠道通过账户进行登录，有则返回用户信息，没有则创建用户------>供后端调用
  async getLoginByUserName(pobj){
    var tmpOpResult = await this.utilsAuthSve.getLoginByUserName(pobj, pobj.actionBody);
    if (tmpOpResult.status != 0 && tmpOpResult.status != 2060) {
        return tmpOpResult;
    }
    opResult = system.getResultSuccess({ userpin: pobj.actionBody.userpin })
    if (tmpOpResult.status == 2060) {
        opResult.msg = tmpOpResult.msg;
        opResult.data.userpin = tmpOpResult.data.userpin;
    }
    return opResult;
  }
  
}
module.exports = feishuLoginService;